#!/usr/bin/env python3
import mrdata

def test_attributes(obj, attr_dict):
    passed = True

    for attr in attr_dict:
        if attr in vars(obj):
            val = getattr(obj, attr)
            exp = attr_dict[attr]
            if type(val) != type(exp):
                print("Instansvariabeln '" + attr + "' är av fel typ, ")
                print("hittade:", type(val), ", väntade:", type(exp))
                print()
                passed = False
            elif val != exp:
                print("Felaktigt värde i instansvariabeln '" + attr + "',")
                print("hittade: " + str(val) + ", väntade: " + str(exp))
                print()
                passed = False
        else:
            print("Hittade inte instansvariabeln '" + attr + "'. ")
            print()
            passed = False

    return passed

def test_error_type(obj):
    def check_single_error(exp):
        if obj.get_error_type() != exp:
            print("Oväntat svar från get_error_type(),")
            print("hittade: " + str(obj.get_error_type()) + ", väntade: " + str(exp))
            print("")
            return False
        return True

    #                 TP            TN             FP              FN
    #            s:r,   c:r     s:nr   c:nr    s:r    c:nr    s:nr   c:r
    expected = [["[n]", "[n]"],["[b]", "[b]"],["[n]", "[b]"],["[b]", "[n]"]]

    passed = True

    for exp in range(len(expected)):
        obj.subjects_answer = expected[exp][0]
        obj.correct_answer = expected[exp][1]

        if not check_single_error(exp):
            passed = False

    obj.subjects_answer = ""
    if not check_single_error(-1):
        passed = False

    return passed


if __name__ == "__main__":
    dr = mrdata.DataRow(1, "R2_3_3_2_0Y0.pct", 1335, "[n]", "[n]", 0)
    expected = {
        "trial": 1,
        "image_file": "R2_3_3_2_0Y0.pct",
        "time": 1335,
        "correct_answer": "[n]",
        "subjects_answer": "[n]",
        "degrees_rotated": 0
    }

    all_correct = True
    if test_attributes(dr, expected):
        print("Instansvariablerna är korrekta i ert DataRow-objekt!")
    else:
        all_correct = False
    if test_error_type(dr):
        print("test_error_type()-metoden fungerar som den ska!")
    else:
        all_correct = False

    if all_correct:
        print("Alla tester godkända.")
